@@ -11,6 +11,7 @@ Support for serialization of numpy data types with msgpack.
 
 import sys
 import functools
+import warnings
 
 import msgpack
 from msgpack import Packer as _Packer, Unpacker as _Unpacker, \
@@ -99,6 +100,10 @@ def decode(obj, chain=None):
     except KeyError:
         return obj if chain is None else chain(obj)
 
+if msgpack.version < (1, 0, 0):
+    warnings.warn('support for msgpack < 1.0.0 will be removed in a future release',
+                   DeprecationWarning)
+
 # Maintain support for msgpack < 0.4.0:
 if msgpack.version < (0, 4, 0):
     class Packer(_Packer):
@@ -135,7 +140,7 @@ elif msgpack.version < (1, 0, 0):
                      unicode_errors='strict',
                      use_single_float=False,
                      autoreset=1,
-                     use_bin_type=0,
+                     use_bin_type=True,
                      strict_types=False):
             default = functools.partial(encode, chain=default)
             super(Packer, self).__init__(default=default,
@@ -147,7 +152,7 @@ elif msgpack.version < (1, 0, 0):
 
     class Unpacker(_Unpacker):
         def __init__(self, file_like=None, read_size=0, use_list=None,
-                     raw=True,
+                     raw=False,
                      object_hook=None,
                      object_pairs_hook=None, list_hook=None,
                      unicode_errors='strict', max_buffer_size=0,
